.. _installation:

***************
Installation
***************

Before you start, make sure you have at least Python 3.10 installed. Then, you can use `pip` to install


.. code-block:: bash

    pip install insightvault


Alternatively, you can clone the repository and build from source:


.. code-block:: bash

    git clone https://github.com/daved01/insightvault.git
    cd insightvault
    pip install .

You can check if the installation was successful by running

.. code-block:: bash

    insightvault --help

You should see some information about ``insightvault``.

Now you can start building local application for summarization, search, and chat! 
If you want to develop on ``insightvault``, see section :ref:`develop` for setup and installation instructions.
